package com.capitalware.ufm.action.objects;

import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the Echo action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class EchoObject extends UFMObject
{
   public String  text = null;

   /**
    * The constructor
    */
   public EchoObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (text != null)
         text  = Tokens.replace(text, paClass.actionProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if (text == null)
         throw new IllegalArgumentException("Error: You must specify a text for the Echo action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     Text                 = " + text);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();
      
      al.add("<"+CWConstants.ECHO_ELEMENT+">");
      al.add(text);
      al.add("</"+CWConstants.ECHO_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }

   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      s = CWConstants.ECHO_ELEMENT+", "+labelName+", "+CWConstants.ECHO_ELEMENT+", Text="+text+LINE_SEPARATOR;

      return s;
   }
}
