package com.capitalware.ufm.action.objects;

import java.io.File;
import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the Move action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class MoveObject extends UFMFileObject
{
   public String     srcFilename = null;
   public String     toFile = null;
   public String     toDir = null;
   public boolean    createDir = false;

   /**
    * The constructor
    */
   public MoveObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (srcFilename != null)
         srcFilename   = Tokens.replace(srcFilename, paClass.actionProperties);
      if (toFile != null)
         toFile = Tokens.replace(toFile, paClass.actionProperties);
      if (toDir != null)
         toDir  = Tokens.replace(toDir, paClass.actionProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      /* Do we need to create the directory? */
      if (createDir)
      {
         if (!(new File(toDir).exists()))
         {
            if ((new File(toDir)).mkdirs())
               UFM.logger.info("Successfully created directory: " + toDir);
            else
               throw new IllegalArgumentException("Error: Cannot create directory: " + toDir);
         }
      }
      else if (!(new File(toDir).exists()))
         throw new IllegalArgumentException("Target directory '"+toDir+"' does not exit.");
      
      if (srcFilename == null)
         throw new IllegalArgumentException("Error: You must specify a filename for the Move action.");

      if (toDir == null)
         throw new IllegalArgumentException("Error: You must specify a TargetDirectory for the Move action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     FileName             = " + srcFilename);
      UFM.logger.info("     Target Directory     = " + toDir);
      UFM.logger.info("     Target File          = " + (toFile == null ? "":toFile));
      UFM.logger.info("     Create Directory     = " + createDir);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();
      String file;

      if (srcFilename.indexOf(File.separator) != -1 )
      {
         int x = srcFilename.lastIndexOf(File.separator);

         String dir   = srcFilename.substring(0, x);
         String fname = srcFilename.substring(x+1);

         file = "<"+CWConstants.FILE_ELEMENT+" "+CWConstants.DIR_ATTRIBUTE+"=\""+dir+"\">"+fname+"</"+CWConstants.FILE_ELEMENT+">";
      }
      else
         file = "<"+CWConstants.FILE_ELEMENT+">"+srcFilename+"</"+CWConstants.FILE_ELEMENT+">";
      
      if (toFile == null)
         al.add("<"+CWConstants.MOVE_ELEMENT+" "+CWConstants.TO_DIR_ATTRIBUTE+"=\""+toDir+"\">"+LINE_SEPARATOR);
      else
         al.add("<"+CWConstants.MOVE_ELEMENT+" "+CWConstants.TO_DIR_ATTRIBUTE+"=\""+toDir+"\" "+CWConstants.TO_FILE_ATTRIBUTE+"\""+toFile+">"+LINE_SEPARATOR);
      
      al.add("  "+file+LINE_SEPARATOR);
      al.add("</"+CWConstants.MOVE_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }

   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      if (toFile == null)
         s = CWConstants.MOVE_ELEMENT+", "+labelName+", "+CWConstants.MOVE_ELEMENT+", "+CWConstants.CREATE_DIR_ATTRIBUTE+"="+createDir+", srcFilename="+srcFilename+", "+CWConstants.TO_DIR_ATTRIBUTE+"="+toDir+LINE_SEPARATOR;
      else
         s = CWConstants.MOVE_ELEMENT+", "+labelName+", "+CWConstants.MOVE_ELEMENT+", "+CWConstants.CREATE_DIR_ATTRIBUTE+"="+createDir+", srcFilename="+srcFilename+", "+CWConstants.TO_DIR_ATTRIBUTE+"="+toDir+", "+CWConstants.TO_FILE_ATTRIBUTE+"="+toFile+LINE_SEPARATOR;

      return s;
   }
}
