package com.capitalware.ufm.action.objects;

import java.io.File;
import java.util.ArrayList;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.handlers.Tokens;
import com.capitalware.ufm.objects.CWConstants;

/**
 * This class holds the values for the UnZip action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class UnZipObject extends UFMFileObject
{
   public String     toDir = null;
   public String     zipFilename = null;
   public boolean    createDir = false;

   /**
    * The constructor
    */
   public UnZipObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (zipFilename != null)
         zipFilename   = Tokens.replace(zipFilename, paClass.actionProperties);
      if (toDir != null)
         toDir = Tokens.replace(toDir, paClass.actionProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      checkAndCreateDirectory(createDir, toDir);

      if (zipFilename == null)
         throw new IllegalArgumentException("Error: You must specify a ToFileName for the UnZip action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     Source File          = " + zipFilename);
      UFM.logger.info("     Target Directory     = " + toDir);
      UFM.logger.info("     Create Directory     = " + createDir);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();
      String file;

      if (zipFilename.indexOf(File.separator) != -1 )
      {
         int x = zipFilename.lastIndexOf(File.separator);

         String dir   = zipFilename.substring(0, x);
         String fname = zipFilename.substring(x+1);

         file = "<"+CWConstants.FILE_ELEMENT+" "+CWConstants.DIR_ATTRIBUTE+"=\""+dir+"\">"+fname+"</"+CWConstants.FILE_ELEMENT+">";
      }
      else
         file = "<"+CWConstants.FILE_ELEMENT+">"+zipFilename+"</"+CWConstants.FILE_ELEMENT+">";
      
      al.add("<"+CWConstants.UNZIP_ELEMENT+" "+CWConstants.TO_DIR_ATTRIBUTE+"=\""+toDir+"\">"+LINE_SEPARATOR);
      al.add("  "+file+LINE_SEPARATOR);
      al.add("</"+CWConstants.UNZIP_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }

   /**
    * Retrieve the values in this action for the status update.
    * @return s
    */
   public String toStringForStatusUpdate(String event)
   {
      String s;

      s = CWConstants.UNZIP_ELEMENT+", "+labelName+", "+CWConstants.UNZIP_ELEMENT+", "+CWConstants.CREATE_DIR_ATTRIBUTE+"="+createDir+", srcFilename="+zipFilename+", "+CWConstants.TO_DIR_ATTRIBUTE+"="+toDir+LINE_SEPARATOR;

      return s;
   }
}
