package com.capitalware.ufm.actions;

import java.io.IOException;
import java.security.InvalidAlgorithmParameterException;
import java.security.NoSuchAlgorithmException;
import java.text.SimpleDateFormat;
import java.util.Date;

import org.jdom.JDOMException;

import com.ibm.mq.MQException;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.MQSendObject;
import com.capitalware.ufm.handlers.InternalMessageQueue;
import com.capitalware.ufm.internal.messages.UpdateStatus;
import com.capitalware.ufm.mq.MQPutFile;
import com.capitalware.ufm.mq.objects.MQObject;
import com.capitalware.ufm.objects.UFMException;
import com.capitalware.ufm.xml.MQXml;

/**
 * This class will handle the action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class MQSendAction extends UFMAction
{
   private MQSendObject    so;
   private InternalMessageQueue    iq = null;

   /**
    * The constructor
    * @param so
    */
   public MQSendAction(MQSendObject so, InternalMessageQueue iq)
   {
      super(so.actionName);
      this.so = so;
      this.iq = iq;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      SimpleDateFormat dateTimeFormat = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
      int exitCode = 0;
      MQPutFile mqh = null;
      so.printValues();

      try
      {
         if (so.mqXMLFile != null)
         {
            MQXml mqX = new MQXml(so.qMgrName, so.qObject, so.CCDTFile);
            mqX.readXMLFile(so.mqXMLFile);
            so.mqo = mqX.getMQObject();
         }
         else
         {
            so.mqo = new MQObject(so.qMgrName, so.qObject, so.CCDTFile);
         }

         so.mqo.checkQM();
         so.mqo.dumpUserParms();
         
         if (iq != null)
            iq.addMessage(new UpdateStatus("0", dateTimeFormat.format(new Date())+", 0, "+so.toStringForStatusUpdate("Starting")));

         mqh = new MQPutFile(so.mqo);

         mqh.connect();

         if (so.srcFilename.indexOf('*') != -1)
            exitCode = mqh.putManyMsgs(so, iq);
         else
            exitCode = mqh.simplePut1(so, iq);
      }
      catch (JDOMException e)
      {
         UFM.logger.fatal("JDOMException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            UFM.logger.fatal(e.getCause().toString());;
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (IOException e)
      {
         UFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            UFM.logger.fatal(e.getCause().toString());;
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (MQException e)
      {
         UFM.logger.fatal("MQException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            UFM.logger.fatal("MQException: " + e.getCause());
         UFM.logger.fatal("MQCC=" + e.completionCode + " : MQRC="+e.reasonCode);
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (UFMException e)
      {
         UFM.logger.fatal("UFMException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (InvalidAlgorithmParameterException e)
      {
         UFM.logger.fatal("InvalidAlgorithmParameterException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (NoSuchAlgorithmException e)
      {
         UFM.logger.fatal("NoSuchAlgorithmException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (ClassNotFoundException e)
      {
         UFM.logger.fatal("ClassNotFoundException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (InstantiationException e)
      {
         UFM.logger.fatal("InstantiationException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (IllegalAccessException e)
      {
         UFM.logger.fatal("IllegalAccessException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (Exception e)
      {
         UFM.logger.fatal(e.getLocalizedMessage());
         if (e.getCause() != null)
            UFM.logger.fatal(e.getCause().toString());;
         UFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      finally
      {
         if ( mqh != null)
            mqh.disconnect();

         if (!so.onErrorFail)
            exitCode = 0; /* reset back to zero */
      }

      return exitCode;
   }
}
