package com.capitalware.ufm.actions;

import com.capitalware.ufm.UFM;
import com.capitalware.ufm.action.objects.SplitObject;
import com.capitalware.ufm.handlers.IO;
import com.capitalware.ufm.objects.UFMException;

/**
 * This class will handle the Split action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class SplitAction extends UFMAction
{
   private SplitObject   so;

   /**
    * The constructor
    * @param sfo
    */
   public SplitAction(SplitObject so)
   {
      super(so.actionName);
      this.so = so;
   }

   /**
    * Perform the work.
    * @return exitCode
    */
   public int doWork()
   {
      int exitCode = 0;
      so.printValues();

      try
      {
         if (so.type == 'B')
            so.fileCount = IO.splitByBytes(so.srcFilename, so.toDir, so.size, so.prefix, so.extension);
         else
            so.fileCount = IO.splitByLines(so.srcFilename, so.toDir, so.size, so.prefix, so.extension);
      }
      catch (UFMException e)
      {
         UFM.logger.fatal("UFMException: " + e.getLocalizedMessage());
         UFM.globalErrorText = e.getLocalizedMessage();
            exitCode = 8;
      }
      finally
      {
         if (!so.onErrorFail)
            exitCode = 0; /* reset back to zero */
      }

      return exitCode;
   }
}
