package com.capitalware.ufm.schedule;

import java.util.Calendar;

import com.capitalware.ufm.UFM;

/**
 * This class holds the values for the Schedule action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class Holiday
{
   public String  name = null;
   public int     day = -1;
   public int     month = -1;
   public int     year = -1;

   /**
    * The constructor
    */
   public Holiday()
   {
      super();
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if ( (day < -1) || (day == 0) || (day > 31) )
         throw new IllegalArgumentException("Error: The DayOfMonth value is invalid. Use '*' or a number between 1 and 31.");

      if ( (month < -1) || (month == 0) || (month > 12) )
         throw new IllegalArgumentException("Error: The month value is invalid. Use '*' or a number between 1 and 12.");

      Calendar c = Calendar.getInstance();
      if ( (year < -1) || ( (year >= 0) && (year < c.get(Calendar.YEAR)) ) )
         throw new IllegalArgumentException("Error: The year value is invalid. Use '*' or a number equal to or higher than the current year.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      UFM.logger.info("     Day                  = " + (day == -1 ? "*" : day));
      UFM.logger.info("     Month                = " + formatIntsToMonth(month));
      UFM.logger.info("     Year                 = " + (year == -1 ? "*" : year));
   }

   /**
    * Convert a string to an int.
    * @param value
    * @return
    */
   public int formatStringToInt(String value)
   {
      int n = -1;
      if ("*".equals(value))
         n = -1;
      else if ( ("".equals(value)) || (value == null) )
         n = -1;
      else
         n = Integer.parseInt(value);
      
      return n;
   }

   /**
    * Convert an array of "int"s to an array of Strings
    * @param value
    * @return 
    */
   private String formatIntsToMonth(int value)
   {
      StringBuffer sb = new StringBuffer(); 
      
      if (value == -1)
         sb.append("*");
      else
      {
         if (value == 0)
            sb.append("JANUARY");
         else if (value == 1)
            sb.append("FEBRUARY");
         else if (value == 2)
            sb.append("MARCH");
         else if (value == 3)
            sb.append("APRIL");
         else if (value == 4)
            sb.append("MAY");
         else if (value == 5)
            sb.append("JUNE");
         else if (value == 6)
            sb.append("JULY");
         else if (value == 7)
            sb.append("AUGUST");
         else if (value == 8)
            sb.append("SEPTEMBER");
         else if (value == 9)
            sb.append("OCTOBER");
         else if (value == 10)
            sb.append("NOVEMBER");
         else if (value == 11)
            sb.append("DECEMBER");
      }
      
      return sb.toString();
   }

   /**
    * Convert 
    * @param value
    * @return
    */
   public int formatMonthToInts(String value)
   {
      int nn = -1;
      if ("*".equals(value))
         nn = -1;
      else if ( ("".equals(value)) || (value == null) )
         nn = -1;
      else
      {
         if ( ("1".equalsIgnoreCase(value)) || ("JAN".equalsIgnoreCase(value)) || ("JANUARY".equalsIgnoreCase(value)) )
            nn = 0;
         else if ( ("2".equalsIgnoreCase(value)) || ("FEB".equalsIgnoreCase(value)) || ("FEBRUARY".equalsIgnoreCase(value)) )
            nn = 1;
         else if ( ("3".equalsIgnoreCase(value)) || ("MAR".equalsIgnoreCase(value)) || ("MARCH".equalsIgnoreCase(value)) )
            nn = 2;
         else if ( ("4".equalsIgnoreCase(value)) || ("APR".equalsIgnoreCase(value)) || ("APRIL".equalsIgnoreCase(value)) )
            nn = 3;
         else if ( ("5".equalsIgnoreCase(value)) || ("MAY".equalsIgnoreCase(value)) )
            nn = 4;
         else if ( ("6".equalsIgnoreCase(value)) || ("JUN".equalsIgnoreCase(value)) || ("JUNE".equalsIgnoreCase(value)) )
            nn = 5;
         else if ( ("7".equalsIgnoreCase(value)) || ("JUL".equalsIgnoreCase(value)) || ("JULY".equalsIgnoreCase(value)) )
            nn = 6;
         else if ( ("8".equalsIgnoreCase(value)) || ("AUG".equalsIgnoreCase(value)) || ("AUGUST".equalsIgnoreCase(value)) )
            nn = 7;
         else if ( ("9".equalsIgnoreCase(value)) || ("SEP".equalsIgnoreCase(value)) || ("SEPTEMBER".equalsIgnoreCase(value)) )
            nn = 8;
         else if ( ("10".equalsIgnoreCase(value)) || ("OCT".equalsIgnoreCase(value)) || ("OCTOBER".equalsIgnoreCase(value)) )
            nn = 9;
         else if ( ("11".equalsIgnoreCase(value)) || ("NOV".equalsIgnoreCase(value)) || ("NOVEMBER".equalsIgnoreCase(value)) )
            nn = 10;
         else if ( ("12".equalsIgnoreCase(value)) || ("DEC".equalsIgnoreCase(value)) || ("DECEMBER".equalsIgnoreCase(value)) )
            nn = 11;
         else
            nn = 99; // errror!!
      }
      
      return nn;
   }
}
