package com.capitalware.ufm.xml.DTDs;

import java.io.IOException;
import java.net.URL;
import java.util.Locale;

import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

/**
 * Resolves a local copy of the DTD in the current JAR file.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public final class ResolveLocalDTD implements EntityResolver
{
   private String    dtdName;
   
   /**
    * The constructor
    * @param dtdName
    */
   public ResolveLocalDTD(String dtdName)
   {
      super();
      this.dtdName = dtdName;
   }

   /**
    * Resolve where this DTD is located.
    * @param  publicId
    * @param  systemId
    * @throws SAXException
    * @throws IOException
    */
   public InputSource resolveEntity(final String publicId, final String systemId) throws SAXException, IOException
   {
      if (!systemId.toLowerCase(Locale.getDefault()).startsWith("http://"))
      {
         URL resource = ResolveLocalDTD.class.getResource(dtdName);

         if (resource != null)
         {
            return new InputSource(resource.openStream());
         }
         else
         {
            /*
             * Should probably not happen, this may indicate that the dtd has
             * been removed from the jar for some reason
             */
            throw new IOException("Could not load dtd resource from jar!!");
         }
      }

      // Must be pulling from the web, stick with default implementation
      return null;
   }
}
